@@ -8,7 +8,6 @@ use hyper::client::*;
 use hyper::http::StatusCode;
 use hyper::{Body, Request, Response, Uri};
 use hyper_rustls::HttpsConnector;
-use log::*;
 use mime::Mime;
 use rvstruct::ValueStruct;
 use slack_morphism::errors::*;
@@ -21,6 +20,7 @@ use std::collections::HashMap;
 use std::io::Read;
 use std::sync::Arc;
 use std::time::Duration;
+use tracing::*;
 use url::Url;
 
 #[derive(Clone, Debug)]
@@ -148,6 +148,13 @@ impl<H: 'static + Send + Sync + Clone + connect::Connect> SlackClientHyperConnec
     where
         RS: for<'de> serde::de::Deserialize<'de>,
     {
+        let uri_str = request.uri().to_string();
+        debug!(
+            slack_uri = uri_str.as_str(),
+            "Sending HTTP request to {}",
+            request.uri()
+        );
+
         let http_res = self
             .hyper_connector
             .request(request)
@@ -163,6 +170,13 @@ impl<H: 'static + Send + Sync + Clone + connect::Connect> SlackClientHyperConnec
             response_mime.type_() == mime::APPLICATION && response_mime.subtype() == mime::JSON
         });
 
+        debug!(
+            slack_uri = uri_str.as_str(),
+            slack_http_status = http_status.as_u16(),
+            "Received HTTP response {}",
+            http_status
+        );
+
         match http_status {
             StatusCode::OK if http_content_is_json => {
                 let slack_message: SlackEnvelopeMessage =
